==> google_cloud_discoveryengine-0.11.13-py3-none-any.whl: google/cloud/discoveryengine_v1alpha/services/conversational_search_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.cloud.location import locations_pb2  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.oauth2 import service_account  # type: ignore
from google.protobuf import empty_pb2  # type: ignore

from google.cloud.discoveryengine_v1alpha import gapic_version as package_version
from google.cloud.discoveryengine_v1alpha.types import conversation as gcd_conversation
from google.cloud.discoveryengine_v1alpha.types import conversational_search_service
from google.cloud.discoveryengine_v1alpha.types import answer
from google.cloud.discoveryengine_v1alpha.types import conversation
from google.cloud.discoveryengine_v1alpha.types import session
from google.cloud.discoveryengine_v1alpha.types import session as gcd_session

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


class ConversationalSearchServiceTransport(abc.ABC):
    """Abstract transport class for ConversationalSearchService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "discoveryengine.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'discoveryengine.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    @property
    def host(self):
        return self._host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.converse_conversation: gapic_v1.method.wrap_method(
                self.converse_conversation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_conversation: gapic_v1.method.wrap_method(
                self.create_conversation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_conversation: gapic_v1.method.wrap_method(
                self.delete_conversation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_conversation: gapic_v1.method.wrap_method(
                self.update_conversation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_conversation: gapic_v1.method.wrap_method(
                self.get_conversation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_conversations: gapic_v1.method.wrap_method(
                self.list_conversations,
                default_timeout=None,
                client_info=client_info,
            ),
            self.answer_query: gapic_v1.method.wrap_method(
                self.answer_query,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_answer: gapic_v1.method.wrap_method(
                self.get_answer,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_session: gapic_v1.method.wrap_method(
                self.create_session,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_session: gapic_v1.method.wrap_method(
                self.delete_session,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_session: gapic_v1.method.wrap_method(
                self.update_session,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_session: gapic_v1.method.wrap_method(
                self.get_session,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_sessions: gapic_v1.method.wrap_method(
                self.list_sessions,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def converse_conversation(
        self,
    ) -> Callable[
        [conversational_search_service.ConverseConversationRequest],
        Union[
            conversational_search_service.ConverseConversationResponse,
            Awaitable[conversational_search_service.ConverseConversationResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_conversation(
        self,
    ) -> Callable[
        [conversational_search_service.CreateConversationRequest],
        Union[gcd_conversation.Conversation, Awaitable[gcd_conversation.Conversation]],
    ]:
        raise NotImplementedError()

    @property
    def delete_conversation(
        self,
    ) -> Callable[
        [conversational_search_service.DeleteConversationRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def update_conversation(
        self,
    ) -> Callable[
        [conversational_search_service.UpdateConversationRequest],
        Union[gcd_conversation.Conversation, Awaitable[gcd_conversation.Conversation]],
    ]:
        raise NotImplementedError()

    @property
    def get_conversation(
        self,
    ) -> Callable[
        [conversational_search_service.GetConversationRequest],
        Union[conversation.Conversation, Awaitable[conversation.Conversation]],
    ]:
        raise NotImplementedError()

    @property
    def list_conversations(
        self,
    ) -> Callable[
        [conversational_search_service.ListConversationsRequest],
        Union[
            conversational_search_service.ListConversationsResponse,
            Awaitable[conversational_search_service.ListConversationsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def answer_query(
        self,
    ) -> Callable[
        [conversational_search_service.AnswerQueryRequest],
        Union[
            conversational_search_service.AnswerQueryResponse,
            Awaitable[conversational_search_service.AnswerQueryResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_answer(
        self,
    ) -> Callable[
        [conversational_search_service.GetAnswerRequest],
        Union[answer.Answer, Awaitable[answer.Answer]],
    ]:
        raise NotImplementedError()

    @property
    def create_session(
        self,
    ) -> Callable[
        [conversational_search_service.CreateSessionRequest],
        Union[gcd_session.Session, Awaitable[gcd_session.Session]],
    ]:
        raise NotImplementedError()

    @property
    def delete_session(
        self,
    ) -> Callable[
        [conversational_search_service.DeleteSessionRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def update_session(
        self,
    ) -> Callable[
        [conversational_search_service.UpdateSessionRequest],
        Union[gcd_session.Session, Awaitable[gcd_session.Session]],
    ]:
        raise NotImplementedError()

    @property
    def get_session(
        self,
    ) -> Callable[
        [conversational_search_service.GetSessionRequest],
        Union[session.Session, Awaitable[session.Session]],
    ]:
        raise NotImplementedError()

    @property
    def list_sessions(
        self,
    ) -> Callable[
        [conversational_search_service.ListSessionsRequest],
        Union[
            conversational_search_service.ListSessionsResponse,
            Awaitable[conversational_search_service.ListSessionsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_operations(
        self,
    ) -> Callable[
        [operations_pb2.ListOperationsRequest],
        Union[
            operations_pb2.ListOperationsResponse,
            Awaitable[operations_pb2.ListOperationsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_operation(
        self,
    ) -> Callable[
        [operations_pb2.GetOperationRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def cancel_operation(
        self,
    ) -> Callable[[operations_pb2.CancelOperationRequest], None,]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("ConversationalSearchServiceTransport",)

==> google_cloud_discoveryengine-0.13.4-py3-none-any.whl: google/cloud/discoveryengine_v1alpha/services/conversational_search_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.cloud.location import locations_pb2  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.oauth2 import service_account  # type: ignore
from google.protobuf import empty_pb2  # type: ignore

from google.cloud.discoveryengine_v1alpha import gapic_version as package_version
from google.cloud.discoveryengine_v1alpha.types import conversation as gcd_conversation
from google.cloud.discoveryengine_v1alpha.types import conversational_search_service
from google.cloud.discoveryengine_v1alpha.types import answer
from google.cloud.discoveryengine_v1alpha.types import conversation
from google.cloud.discoveryengine_v1alpha.types import session
from google.cloud.discoveryengine_v1alpha.types import session as gcd_session

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


class ConversationalSearchServiceTransport(abc.ABC):
    """Abstract transport class for ConversationalSearchService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "discoveryengine.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'discoveryengine.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes
        if not hasattr(self, "_ignore_credentials"):
            self._ignore_credentials: bool = False

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None and not self._ignore_credentials:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    @property
    def host(self):
        return self._host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.converse_conversation: gapic_v1.method.wrap_method(
                self.converse_conversation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_conversation: gapic_v1.method.wrap_method(
                self.create_conversation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_conversation: gapic_v1.method.wrap_method(
                self.delete_conversation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_conversation: gapic_v1.method.wrap_method(
                self.update_conversation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_conversation: gapic_v1.method.wrap_method(
                self.get_conversation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_conversations: gapic_v1.method.wrap_method(
                self.list_conversations,
                default_timeout=None,
                client_info=client_info,
            ),
            self.answer_query: gapic_v1.method.wrap_method(
                self.answer_query,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_answer: gapic_v1.method.wrap_method(
                self.get_answer,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_session: gapic_v1.method.wrap_method(
                self.create_session,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_session: gapic_v1.method.wrap_method(
                self.delete_session,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_session: gapic_v1.method.wrap_method(
                self.update_session,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_session: gapic_v1.method.wrap_method(
                self.get_session,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_sessions: gapic_v1.method.wrap_method(
                self.list_sessions,
                default_timeout=None,
                client_info=client_info,
            ),
            self.cancel_operation: gapic_v1.method.wrap_method(
                self.cancel_operation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_operation: gapic_v1.method.wrap_method(
                self.get_operation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_operations: gapic_v1.method.wrap_method(
                self.list_operations,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def converse_conversation(
        self,
    ) -> Callable[
        [conversational_search_service.ConverseConversationRequest],
        Union[
            conversational_search_service.ConverseConversationResponse,
            Awaitable[conversational_search_service.ConverseConversationResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_conversation(
        self,
    ) -> Callable[
        [conversational_search_service.CreateConversationRequest],
        Union[gcd_conversation.Conversation, Awaitable[gcd_conversation.Conversation]],
    ]:
        raise NotImplementedError()

    @property
    def delete_conversation(
        self,
    ) -> Callable[
        [conversational_search_service.DeleteConversationRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def update_conversation(
        self,
    ) -> Callable[
        [conversational_search_service.UpdateConversationRequest],
        Union[gcd_conversation.Conversation, Awaitable[gcd_conversation.Conversation]],
    ]:
        raise NotImplementedError()

    @property
    def get_conversation(
        self,
    ) -> Callable[
        [conversational_search_service.GetConversationRequest],
        Union[conversation.Conversation, Awaitable[conversation.Conversation]],
    ]:
        raise NotImplementedError()

    @property
    def list_conversations(
        self,
    ) -> Callable[
        [conversational_search_service.ListConversationsRequest],
        Union[
            conversational_search_service.ListConversationsResponse,
            Awaitable[conversational_search_service.ListConversationsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def answer_query(
        self,
    ) -> Callable[
        [conversational_search_service.AnswerQueryRequest],
        Union[
            conversational_search_service.AnswerQueryResponse,
            Awaitable[conversational_search_service.AnswerQueryResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_answer(
        self,
    ) -> Callable[
        [conversational_search_service.GetAnswerRequest],
        Union[answer.Answer, Awaitable[answer.Answer]],
    ]:
        raise NotImplementedError()

    @property
    def create_session(
        self,
    ) -> Callable[
        [conversational_search_service.CreateSessionRequest],
        Union[gcd_session.Session, Awaitable[gcd_session.Session]],
    ]:
        raise NotImplementedError()

    @property
    def delete_session(
        self,
    ) -> Callable[
        [conversational_search_service.DeleteSessionRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def update_session(
        self,
    ) -> Callable[
        [conversational_search_service.UpdateSessionRequest],
        Union[gcd_session.Session, Awaitable[gcd_session.Session]],
    ]:
        raise NotImplementedError()

    @property
    def get_session(
        self,
    ) -> Callable[
        [conversational_search_service.GetSessionRequest],
        Union[session.Session, Awaitable[session.Session]],
    ]:
        raise NotImplementedError()

    @property
    def list_sessions(
        self,
    ) -> Callable[
        [conversational_search_service.ListSessionsRequest],
        Union[
            conversational_search_service.ListSessionsResponse,
            Awaitable[conversational_search_service.ListSessionsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_operations(
        self,
    ) -> Callable[
        [operations_pb2.ListOperationsRequest],
        Union[
            operations_pb2.ListOperationsResponse,
            Awaitable[operations_pb2.ListOperationsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_operation(
        self,
    ) -> Callable[
        [operations_pb2.GetOperationRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def cancel_operation(
        self,
    ) -> Callable[[operations_pb2.CancelOperationRequest], None,]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("ConversationalSearchServiceTransport",)
